==> v1.9.tar.gz: ubl-settings-diskquota/source/ubl-strings.h <==
#include <locale.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <gtk/gtkx.h>
#include <libintl.h>
#include <libintl.h>
#define _(String) gettext(String)


#define HELP_LABEL yon_char_unite(_("ubl-settings-diskquota version:")," ", version_application,"\n","\n",_("Usage:"), " ubl-settings-diskquota ",_("[OPTIONS]"),"\n",_("Options:"),"\n\t--help, -h\t\t\t",_("Show this help"),"\n\t--version, -V\t\t\t",_("Show package version"),"\n\t--lock-help\t\t\t",_("Lock this help menu"),"\n\t--lock-save\t\t\t",_("Lock configuration saving"),"\n\t--lock-save-local\t\t",_("Lock local configration saving"),"\n\t--lock-save-global\t\t",_("Lock global configration saving"),"\n\t--lock-load-global\t\t",_("Lock global configration loading"),"\n",NULL)

#define TITLE_LABEL _("Disk quotas")
#define TITLE_INFO_LABEL _("Configuring disk quota settings for system groups and users")

#define SUCCESS_LABEL _("Operation succeeded")
#define ROOT_WARNING_LABEL _("Warning! Application was launched without root - root-dependent actions are locked.")

#define ABOUT_LABEL _("About")
#define DOCUMENTATION_LABEL _("Documentation")

#define SAVE_LOCAL_LABEL _("Save to local configuration")
#define SAVE_GLOBAL_LABEL _("Save to global configuration")
#define SAVE_CONFIGURATION_LABEL _("Save configuration")
#define SAVE_LABEL _("Save")

#define LOAD_LOCAL_LABEL _("Load local configuration")
#define LOAD_GLOBAL_LABEL _("Load global configuration")
#define LOAD_LABEL _("Load")

#define CANCEL_LABEL _("Cancel")

#define HELP_TITLE_LABEL _("Would you like to read documentation in the Web?")
#define HELP_INFO_LABEL _("You will be redirected to documentation website where documentation is\ntranslated and supported by community.")
#define HELP_ALWAYS_OPEN_LABEL _("Always redirect to online documentation")
#define OPEN_HELP_LABEL _("Open documentation")
#define PROJECT_HOME_LABEL _("Project Home Page")
#define NOTHING_CHOSEN_LABEL _("Nothing were chosen")


#define GLOBAL_LOAD_SUCCESS_LABEL _("Global configuration loading succseeded.")
#define LOCAL_LOAD_SUCCESS_LABEL _("Local configuration loading succseeded.")
#define LOAD_FAILED_LABEL _("Config loading failed")

#define GLOBAL_LOCAL_SAVE_SUCCESS_LABEL _("Local and global configuration saving succseeded.")
#define GLOBAL_SAVE_SUCCESS_LABEL _("Global configuration saving succseeded.")
#define LOCAL_SAVE_SUCCESS_LABEL _("Local configuration saving succseeded.")
#define MESS_NOTHING_SAVE _("Nothing to save!")

#define STR_KB _("Kb")
#define STR_MB _("Mb")
#define STR_GB _("Gb")
#define STR_TB _("Tb")


#define CMD_LOAD_GLOBAL "ubconfig --default --source global get security DISK_QUOTA[*]"
#define CMD_LOAD_SYSTEM "ubconfig --default --source system get security DISK_QUOTA[*]"
#define CMD_SAVE_GLOBAL "ubconfig --target global set security"
#define CMD_SAVE_SYSTEM "ubconfig --target system set security"
#define CMD_ALL_SAVE "ubconfig set security "
#define CMD_ALL_REMOVE "ubconfig remove security "
#define CMD_REMOVE_GLOBAL "ubconfig --target global --noexecute remove security "
#define CMD_REMOVE_SYSTEM "ubconfig --target system remove security "

#define empty_str "-"
#define WEEKS _("w ")
#define DAYS _("d ")
#define HOURS _("h ")
#define MINUTES _("m ")

#define STR_ON _("On")
#define STR_OFF _("Off")
#define STR_NOT_SET _("Not set")
#define STR_TITLE_ADD_QUOTAS _("Settings quotas - Addition")
#define STR_TITLE_EDIT_QUOTAS _("Settings quotas - Editing")

#define SAVE_FAILED_LABEL

#define STR_TITLE_FILE_MANGER _("Please select folder")

#define STR_USER _("User")
#define STR_GROUP _("Group")
#define STR_PROJECT _("Project")
#define STR_USERS _("Users")
#define STR_GROUPS _("Groups")

#define STR_ERROR_MESS_NOT_DIR _("Is not a directory")
#define STR_CHK_LABEL_WRITE_ALL_USERS _("Withdraw all users")
#define STR_CHK_LABEL_WRITE_ALL_GROUPS _("Withdraw all groups")

#define STR_ERROR_ERROR_PROJECT_ID _("Project ID mandatory field")
#define STR_ERROR_PATH_IS_DISK_FALSE_1 _("The path does not match the specified disk")
#define STR_ERROR_PROJECT_NAME_VALUE_NULL _("Project name mandatory field")
#define STR_ERROR_PROJECT_NAME_ENTER_VALUE _("Project name required field")
#define STR_ERROR_LIST_USER_NULL _("The list of users is empty")
#define STR_ERROR_NO_SELECTED_DISK _("To save, you need to select a disk")
#define STR_ERROR_ENTRY_VALUE_VOLUME_OR_FILES _("Insert at leat one value before saving")
#define STR_ERROR_PATH_IS_DISK_FALSE _("The selected directory is not located on the target device")

#define ADD_LABEL _("Add")
#define UPDATE_LABEL _("Update")
#define CANCEL_LABEL _("Cancel")
#define SAVE_LABEL _("Save")

==> v2.2.tar.gz: ubl-settings-diskquota/source/ubl-strings.h <==
#include <locale.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <gtk/gtkx.h>
#include <libintl.h>
#include <libintl.h>
#define _(String) gettext(String)


#define HELP_LABEL yon_char_unite(_("ubl-settings-diskquota version:")," ", version_application,"\n","\n",_("Usage:"), " ubl-settings-diskquota ",_("[OPTIONS]"),"\n",_("Options:"),"\n\t--help, -h\t\t\t",_("Show this help"),"\n\t--version, -V\t\t\t",_("Show package version"),"\n\t--lock-help\t\t\t",_("Lock this help menu"),"\n\t--lock-save\t\t\t",_("Lock configuration saving"),"\n\t--lock-save-local\t\t",_("Lock local configration saving"),"\n\t--lock-save-global\t\t",_("Lock global configration saving"),"\n\t--lock-load-global\t\t",_("Lock global configration loading"),"\n",NULL)

#define TITLE_LABEL _("Disk quotas")
#define TITLE_INFO_LABEL _("Configuring disk quota settings for system groups and users")

#define SUCCESS_LABEL _("Operation succeeded")
#define ROOT_WARNING_LABEL _("Warning! Application was launched without root - root-dependent actions are locked.")

#define ABOUT_LABEL _("About")
#define DOCUMENTATION_LABEL _("Documentation")

#define SAVE_LOCAL_LABEL _("Save to local configuration")
#define SAVE_GLOBAL_LABEL _("Save to global configuration")
#define SAVE_CONFIGURATION_LABEL _("Save configuration")
#define SAVE_LABEL _("Save")

#define LOAD_LOCAL_LABEL _("Load local configuration")
#define LOAD_GLOBAL_LABEL _("Load global configuration")
#define LOAD_LABEL _("Load")

#define CANCEL_LABEL _("Cancel")

#define HELP_TITLE_LABEL _("Would you like to read documentation in the Web?")
#define HELP_INFO_LABEL _("You will be redirected to documentation website where documentation is\ntranslated and supported by community.")
#define HELP_ALWAYS_OPEN_LABEL _("Always redirect to online documentation")
#define OPEN_HELP_LABEL _("Open documentation")
#define PROJECT_HOME_LABEL _("Project Home Page")
#define NOTHING_CHOSEN_LABEL _("Nothing were chosen")


#define GLOBAL_LOAD_SUCCESS_LABEL _("Global configuration loading succseeded.")
#define LOCAL_LOAD_SUCCESS_LABEL _("Local configuration loading succseeded.")
#define LOAD_FAILED_LABEL _("Config loading failed")

#define GLOBAL_LOCAL_SAVE_SUCCESS_LABEL _("Local and global configuration saving succseeded.")
#define GLOBAL_SAVE_SUCCESS_LABEL _("Global configuration saving succseeded.")
#define LOCAL_SAVE_SUCCESS_LABEL _("Local configuration saving succseeded.")
#define MESS_NOTHING_SAVE _("Nothing to save!")

#define STR_KB _("Kb")
#define STR_MB _("Mb")
#define STR_GB _("Gb")
#define STR_TB _("Tb")


#define CMD_LOAD_GLOBAL "ubconfig --default --source global get security DISK_QUOTA[*]"
#define CMD_LOAD_SYSTEM "ubconfig --default --source system get security DISK_QUOTA[*]"
#define CMD_SAVE_GLOBAL "ubconfig --target global set security"
#define CMD_SAVE_SYSTEM "ubconfig --target system set security"
#define CMD_ALL_SAVE "ubconfig set security "
#define CMD_ALL_REMOVE "ubconfig remove security "
#define CMD_REMOVE_GLOBAL "ubconfig --target global --noexecute remove security "
#define CMD_REMOVE_SYSTEM "ubconfig --target system remove security "

#define empty_str "-"
#define WEEKS _("w ")
#define DAYS _("d ")
#define HOURS _("h ")
#define MINUTES _("m ")

#define STR_ON _("On")
#define STR_OFF _("Off")
#define STR_NOT_SET _("Not set")
#define STR_TITLE_ADD_QUOTAS _("Settings quotas - Addition")
#define STR_TITLE_EDIT_QUOTAS _("Settings quotas - Editing")

#define SAVE_FAILED_LABEL

#define STR_TITLE_FILE_MANGER _("Please select folder")

#define STR_USER _("User")
#define STR_GROUP _("Group")
#define STR_PROJECT _("Project")
#define STR_USERS _("Users")
#define STR_GROUPS _("Groups")

#define STR_ERROR_MESS_NOT_DIR _("Is not a directory")
#define STR_CHK_LABEL_WRITE_ALL_USERS _("Withdraw all users")
#define STR_CHK_LABEL_WRITE_ALL_GROUPS _("Withdraw all groups")

#define STR_ERROR_ERROR_PROJECT_ID _("Project ID mandatory field")
#define STR_ERROR_PATH_IS_DISK_FALSE_1 _("The path does not match the specified disk")
#define STR_ERROR_PROJECT_NAME_VALUE_NULL _("Project name mandatory field")
#define STR_ERROR_PROJECT_NAME_ENTER_VALUE _("Project name required field")
#define STR_ERROR_LIST_USER_NULL _("The list of users is empty")
#define STR_ERROR_NO_SELECTED_DISK _("To save, you need to select a disk")
#define STR_ERROR_ENTRY_VALUE_VOLUME_OR_FILES _("Insert at least one value before saving")
#define STR_ERROR_PATH_IS_DISK_FALSE _("The selected directory is not located on the target device")

#define ADD_LABEL _("Add")
#define UPDATE_LABEL _("Update")
#define CANCEL_LABEL _("Cancel")
#define SAVE_LABEL _("Save")
